Class: Agent::Lock::CLI::Commands::SkillInstall

Inherits:
Base
  • Object
show all
Defined in:
lib/agent/lock/cli/commands/skill.rb

Overview

Copy the bundled skill into a skills directory, so an agent learns how to claim files before it first needs to.

Instance Attribute Summary

Attributes inherited from Base

#launcher

Instance Method Summary collapse

Methods inherited from Base

inherited, #initialize

Constructor Details

This class inherits a constructor from Agent::Lock::CLI::Commands::Base

Instance Method Details

#call(**options) ⇒ Object

Parameters:

  • options (Hash)


36
37
38
39
40
41
42
43
# File 'lib/agent/lock/cli/commands/skill.rb', line 36

def call(**options)
  into = destination_for(options)
  skill = into ? Skill.new(into: into) : Skill.new

  result = skill.install(force: options[:force])
  report(result)
  finish(result)
end