Exception: Agent::Lock::Error
- Inherits:
-
StandardError
- Object
- StandardError
- Agent::Lock::Error
- Defined in:
- lib/agent/lock/error.rb
Overview
The base of everything this gem raises. In a file of its own so that any part of the library can require it without reaching for the entry point, which would require the part doing the asking.